@@ -5,9 +5,9 @@
  *
  * This file contains functions needed to handle mime messages.
  *
- * @copyright &copy; 2003-2009 The SquirrelMail Project Team
+ * @copyright &copy; 2003-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: Message.class.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: Message.class.php,v 1.37 2006/01/23 18:39:32 tokul Exp $
  * @package squirrelmail
  * @subpackage mime
  * @since 1.3.2
@@ -30,11 +30,6 @@ class Message {
      * @var object
      */
     var $rfc822_header = '';
-    /**
-     * Headers from original email in reply
-     * @var string 
-     */
-    var $reply_rfc822_header = '';
     /**
      * MessageHeader object
      * @var object
@@ -362,7 +357,7 @@ class Message {
                                 $hdr = new MessageHeader();
                                 $hdr->type0 = 'text';
                                 $hdr->type1 = 'plain';
-                                $hdr->encoding = '7bit';
+                                $hdr->encoding = 'us-ascii';
                             } else {
                                 $msg->header->type0 = 'multipart';
                                 $msg->type0 = 'multipart';
@@ -619,19 +614,18 @@ class Message {
 
         if (count($arg_a) > 9) {
             $d = strtr($arg_a[0], array('  ' => ' '));
-            $d_parts = explode(' ', $d);
-            if (!$arg_a[1]) $arg_a[1] = _("(no subject)");
+            $d = explode(' ', $d);
+        if (!$arg_a[1]) $arg_a[1] = _("(no subject)");
 
-            $hdr->date = getTimeStamp($d_parts); /* argument 1: date */
-            $hdr->date_unparsed = strtr($d,'<>','  '); /* original date */
+            $hdr->date = getTimeStamp($d); /* argument 1: date */
             $hdr->subject = $arg_a[1];     /* argument 2: subject */
             $hdr->from = is_array($arg_a[2]) ? $arg_a[2][0] : '';     /* argument 3: from        */
             $hdr->sender = is_array($arg_a[3]) ? $arg_a[3][0] : '';   /* argument 4: sender      */
-            $hdr->reply_to = is_array($arg_a[4]) ? $arg_a[4][0] : '';  /* argument 5: reply-to    */
+            $hdr->replyto = is_array($arg_a[4]) ? $arg_a[4][0] : '';  /* argument 5: reply-to    */
             $hdr->to = $arg_a[5];          /* argument 6: to          */
             $hdr->cc = $arg_a[6];          /* argument 7: cc          */
             $hdr->bcc = $arg_a[7];         /* argument 8: bcc         */
-            $hdr->in_reply_to = $arg_a[8];   /* argument 9: in-reply-to */
+            $hdr->inreplyto = $arg_a[8];   /* argument 9: in-reply-to */
             $hdr->message_id = $arg_a[9];  /* argument 10: message-id */
         }
         return $hdr;
@@ -664,25 +658,14 @@ class Message {
     }
 
     /**
-     * function parseQuote
-     *
-     * This extract the string value from a quoted string. After the end-quote
-     * character is found it returns the string. The offset $i when calling
-     * this function points to the first double quote. At the end it points to
-     * The ending quote. This function takes care of escaped double quotes.
-     * "some \"string\""
-     * ^               ^
-     * initial $i      end position $i
-     *
      * @param string $read
-     * @param integer $i offset in $read
-     * @return string string inbetween the double quotes
-     * @author Marc Groot Koerkamp
+     * @param integer $i
+     * @return string
+     * @todo document me
      */
     function parseQuote($read, &$i) {
         $s = '';
         $iPos = ++$i;
-        $iPosStart = $iPos;
         while (true) {
             $iPos = strpos($read,'"',$iPos);
             if (!$iPos) break;
@@ -690,38 +673,6 @@ class Message {
                 $s = substr($read,$i,($iPos-$i));
                 $i = $iPos;
                 break;
-            } else if ($iPos > 1 && $read{$iPos -1} == '\\' && $read{$iPos-2} == '\\') {
-                // This is an unique situation where the fast detection of the string
-                // fails. If the quote string ends with \\ then we need to iterate
-                // through the entire string to make sure we detect the unexcaped
-                // double quotes correctly.
-                $s = '';
-                $bEscaped = false;
-                $k = 0;
-                 for ($j=$iPosStart,$iCnt=strlen($read);$j<$iCnt;++$j) {
-                    $cChar = $read{$j};
-                    switch ($cChar) {
-                        case '\\':
-                           $bEscaped = !$bEscaped;
-                            $s .= $cChar;
-                            break;
-                         case '"':
-                            if ($bEscaped) {
-                                $s .= $cChar;
-                                $bEscaped = false;
-                            } else {
-                                $i = $j;
-                                break 3;
-                            }
-                            break;
-                         default:
-                            if ($bEscaped) {
-                               $bEscaped = false;
-                            }
-                            $s .= $cChar;
-                            break;
-                    }
-                }
             }
             ++$iPos;
             if ($iPos > strlen($read)) {
@@ -825,7 +776,7 @@ class Message {
      * @return integer
      */
     function parseParenthesis($read, $i) {
-        for ($i++; $read{$i} != ')'; ++$i) {
+        for (; $read{$i} != ')'; ++$i) {
             switch ($read{$i}) {
                 case '"': $this->parseQuote($read, $i); break;
                 case '{': $this->parseLiteral($read, $i); break;
@@ -960,8 +911,8 @@ class Message {
                     if ((count($this->entities) == 0) &&
                             (!isset($this->header->parameters['filename'])) &&
                             (!isset($this->header->parameters['name'])) &&
-                            (isset($this->header->disposition) && is_object($this->header->disposition) &&
-                             strtolower($this->header->disposition->name) != 'attachment')) {
+                            isset($this->header->disposition) && is_object($this->header->disposition) &&
+                            !(is_object($this->header->disposition) && strtolower($this->header->disposition->name) == 'attachment')) {
                         $entity[] = $this->entity_id;
                         $found = true;
                     }
@@ -1090,6 +1041,7 @@ class Message {
         $attachment = new Message();
         $mime_header = new MessageHeader();
         $mime_header->setParameter('name', $name);
+        // FIXME: duplicate code. see ContentType class
         $pos = strpos($type, '/');
         if ($pos > 0) {
             $mime_header->type0 = substr($type, 0, $pos);
@@ -1107,15 +1059,11 @@ class Message {
 
     /**
      * Delete all attachments from this object from disk.
-     * @since 1.4.6
+     * @since 1.5.1
      */
     function purgeAttachments() {
-        if ($this->att_local_name) {
-            global $username, $attachment_dir;
-            $hashed_attachment_dir = getHashedDir($username, $attachment_dir);
-            if ( file_exists($hashed_attachment_dir . '/' . $this->att_local_name) ) {
-                unlink($hashed_attachment_dir . '/' . $this->att_local_name);
-            }
+        if ($this->att_local_name && file_exists($this->att_local_name)) {
+            unlink($this->att_local_name);
         }
         // recursively delete attachments from entities contained in this object
         for ($i=0, $entCount=count($this->entities);$i< $entCount; ++$i) {
@@ -1124,3 +1072,4 @@ class Message {
     }
 }
 
+?>
