@@ -5,9 +5,9 @@
  *
  * This file contains functions needed to handle headers in mime messages.
  *
- * @copyright 2003-2010 The SquirrelMail Project Team
+ * @copyright &copy; 2003-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: Rfc822Header.class.php 13893 2010-01-25 02:47:41Z pdontthink $
+ * @version $Id: Rfc822Header.class.php,v 1.53 2006/01/23 18:39:32 tokul Exp $
  * @package squirrelmail
  * @subpackage mime
  * @since 1.3.2
@@ -29,11 +29,6 @@ class Rfc822Header {
      * @var mixed
      */
     var $date = -1;
-    /**
-     * Original date header as fallback for unparsable dates
-     * @var mixed
-     */
-    var $date_unparsed = '';
     /**
      * Subject header
      * @var string
@@ -93,7 +88,8 @@ class Rfc822Header {
      */
     var $mime = false;
     /**
-     * @var mixed
+     * Content Type object
+     * @var object
      */
     var $content_type = '';
     /**
@@ -121,12 +117,15 @@ class Rfc822Header {
     /**
      * @var mixed
      */
-    var $mlist = array();
+    var $content_id = '';
     /**
-     * SpamAssassin 'x-spam-status' header
      * @var mixed
      */
-    var $x_spam_status = array();
+    var $content_desc = '';
+    /**
+     * @var mixed
+     */
+    var $mlist = array();
     /**
      * Extra header
      * only needed for constructing headers in delivery class
@@ -181,7 +180,9 @@ class Rfc822Header {
                         }
                         $result .= $value{$i};
                     }
-                    $result .= $value{$i};
+                    if($i < $cnt) {
+                        $result .= $value{$i};
+                    }
                     break;
                 case '(':
                     $depth = 1;
@@ -222,7 +223,6 @@ class Rfc822Header {
                 $d = strtr($value, array('  ' => ' '));
                 $d = explode(' ', $d);
                 $this->date = getTimeStamp($d);
-                $this->date_unparsed = strtr($value,'<>','  ');
                 break;
             case 'subject':
                 $this->subject = $value;
@@ -278,6 +278,16 @@ class Rfc822Header {
                 $value = $this->stripComments($value);
                 $this->parseDisposition($value);
                 break;
+            case 'content-transfer-encoding':
+                $this->encoding = $value;
+                break;
+            case 'content-description':
+                $this->content_desc = $value;
+                break;
+            case 'content-id':
+                $value = $this->stripComments($value);
+                $this->content_id = $value;
+                break;
             case 'user-agent':
             case 'x-mailer':
                 $this->xmailer = $value;
@@ -319,9 +329,6 @@ class Rfc822Header {
                 $value = $this->stripComments($value);
                 $this->mlist('id', $value);
                 break;
-            case 'x-spam-status':
-                $this->x_spam_status = $this->parseSpamStatus($value);
-                break;
             default:
                 break;
         }
@@ -333,7 +340,6 @@ class Rfc822Header {
      */
     function getAddressTokens($address) {
         $aTokens = array();
-        $aAddress = array();
         $aSpecials = array('(' ,'<' ,',' ,';' ,':');
         $aReplace =  array(' (',' <',' ,',' ;',' :');
         $address = str_replace($aSpecials,$aReplace,$address);
@@ -480,7 +486,7 @@ class Rfc822Header {
             $sComment = trim(implode(' ',$aComment));
             $sPersonal .= $sComment;
         }
-        $oAddr = new AddressStructure();
+        $oAddr =& new AddressStructure();
         if ($sPersonal && substr($sPersonal,0,2) == '=?') {
             $oAddr->personal = encodeHeader($sPersonal);
         } else {
@@ -519,7 +525,7 @@ class Rfc822Header {
      */
     function parseAddress($address,$ar=false,$aAddress=array(),$sGroup='',$sHost='',$lookup=false) {
         $aTokens = $this->getAddressTokens($address);
-        $sPersonal = $sEmail = $sComment = $sGroup = '';
+        $sPersonal = $sEmail = $sGroup = '';
         $aStack = $aComment = array();
         foreach ($aTokens as $sToken) {
             $cChar = $sToken{0};
@@ -537,7 +543,7 @@ class Rfc822Header {
                 if ($sGroup) {
                     $aAddress[] = $this->createAddressObject($aStack,$aComment,$sEmail,$sGroup);
                     $oAddr = end($aAddress);
-                    if(!$oAddr || ((isset($oAddr)) && !strlen($oAddr->mailbox) && !$oAddr->personal)) {
+                    if(!$oAddr || ((isset($oAddr)) && !$oAddr->mailbox && !$oAddr->personal)) {
                         $sEmail = $sGroup . ':;';
                     }
                     $aAddress[] = $this->createAddressObject($aStack,$aComment,$sEmail,$sGroup);
@@ -578,13 +584,8 @@ class Rfc822Header {
                          $aAddrBookAddress = $this->parseAddress($aAddr['email'],true);
                      } else {
                          $iPosAt = strpos($aAddr['email'], '@');
-                         if ($iPosAt === FALSE) {
-                             $oAddr->mailbox = $aAddr['email'];
-                             $oAddr->host = FALSE;
-                         } else {
-                             $oAddr->mailbox = substr($aAddr['email'], 0, $iPosAt);
-                             $oAddr->host = substr($aAddr['email'], $iPosAt+1);
-                         }
+                         $oAddr->mailbox = substr($aAddr['email'], 0, $iPosAt);
+                         $oAddr->host = substr($aAddr['email'], $iPosAt+1);
                          if (isset($aAddr['name'])) {
                              $oAddr->personal = $aAddr['name'];
                          } else {
@@ -593,18 +594,18 @@ class Rfc822Header {
                      }
                  }
             }
-            if (!$grouplookup && !strlen($oAddr->mailbox)) {
+            if (!$grouplookup && !$oAddr->mailbox) {
                 $oAddr->mailbox = trim($sEmail);
-                if ($sHost && strlen($oAddr->mailbox)) {
+                if ($sHost && $oAddr->mailbox) {
                     $oAddr->host = $sHost;
                 }
             } else if (!$grouplookup && !$oAddr->host) {
-                if ($sHost && strlen($oAddr->mailbox)) {
+                if ($sHost && $oAddr->mailbox) {
                     $oAddr->host = $sHost;
                 }
             }
           }
-          if (!$aAddrBookAddress && strlen($oAddr->mailbox)) {
+          if (!$aAddrBookAddress && $oAddr->mailbox) {
               $aProcessedAddress[] = $oAddr;
           } else {
               $aProcessedAddress = array_merge($aProcessedAddress,$aAddrBookAddress);
@@ -613,10 +614,7 @@ class Rfc822Header {
         if ($ar) {
             return $aProcessedAddress;
         } else {
-            if (isset($aProcessedAddress[0]))
-                return $aProcessedAddress[0];
-            else
-                return '';
+            return $aProcessedAddress[0];
         }
     }
 
@@ -635,7 +633,7 @@ class Rfc822Header {
      */
     function parsePriority($sValue) {
         // don't use function call inside array_shift.
-        $aValue = preg_split('/\s/',trim($sValue));
+        $aValue = split('/\w/',trim($sValue));
         $value = strtolower(array_shift($aValue));
 
         if ( is_numeric($value) ) {
@@ -778,53 +776,6 @@ class Rfc822Header {
         $this->mlist[$field] = $res_a;
     }
 
-    /**
-     * Parses the X-Spam-Status header
-     * @param string $value
-     */
-    function parseSpamStatus($value) {
-        // Header value looks like this:
-        // No, score=1.5 required=5.0 tests=MSGID_FROM_MTA_ID,NO_REAL_NAME,UPPERCASE_25_50 autolearn=disabled version=3.1.0-gr0
-
-        $spam_status = array();
-
-        if (preg_match ('/^(No|Yes),\s+score=(-?\d+\.\d+)\s+required=(-?\d+\.\d+)\s+tests=(.*?)\s+autolearn=(.*?)\s+version=(.+?)$/', $value, $matches)) {
-            // full header
-            $spam_status['bad_format'] = 0;
-            $spam_status['value'] = $matches[0];
-            // is_spam
-            if (isset($matches[1])
-                && strtolower($matches[1]) == 'yes') {
-                $spam_status['is_spam'] = true;
-            } else {
-                $spam_status['is_spam'] = false;
-            }
-
-            // score
-            $spam_status['score'] = $matches[2];
-
-            // required
-            $spam_status['required'] = $matches[3];
-
-            // tests
-            $tests = array();
-            $tests = explode(',', $matches[4]);
-            foreach ($tests as $test) {
-                $spam_status['tests'][] = trim($test);
-            }
-
-            // autolearn
-            $spam_status['autolearn'] = $matches[5];
-
-            // version
-            $spam_status['version'] = $matches[6];
-        } else {
-            $spam_status['bad_format'] = 1;
-            $spam_status['value'] = $value;
-        }
-        return $spam_status;
-    }
-
     /**
      * function to get the address strings out of the header.
      * example1: header->getAddr_s('to').
@@ -913,7 +864,6 @@ class Rfc822Header {
     }
 
     /**
-//FIXME: This needs some documentation (inside the function too)!  Don't code w/out comments!
      * @param mixed $address array or string
      * @param boolean $recurs
      * @return mixed array, boolean
@@ -925,7 +875,6 @@ class Rfc822Header {
             $i=0;
             foreach($address as $argument) {
                 $match = $this->findAddress($argument, true);
-                $last = end($match);
                 if ($match[1]) {
                     return $i;
                 } else {
@@ -937,14 +886,13 @@ class Rfc822Header {
             }
         } else {
             if (!is_array($this->cc)) $this->cc = array();
-            if (!is_array($this->to)) $this->to = array();
             $srch_addr = $this->parseAddress($address);
             $results = array();
             foreach ($this->to as $to) {
-                if (strtolower($to->host) == strtolower($srch_addr->host)) {
-                    if (strtolower($to->mailbox) == strtolower($srch_addr->mailbox)) {
+                if ($to->host == $srch_addr->host) {
+                    if ($to->mailbox == $srch_addr->mailbox) {
                         $results[] = $srch_addr;
-                        if (strtolower($to->personal) == strtolower($srch_addr->personal)) {
+                        if ($to->personal == $srch_addr->personal) {
                             if ($recurs) {
                                 return array($results, true);
                             } else {
@@ -955,10 +903,10 @@ class Rfc822Header {
                 }
             }
             foreach ($this->cc as $cc) {
-                if (strtolower($cc->host) == strtolower($srch_addr->host)) {
-                    if (strtolower($cc->mailbox) == strtolower($srch_addr->mailbox)) {
+                if ($cc->host == $srch_addr->host) {
+                    if ($cc->mailbox == $srch_addr->mailbox) {
                         $results[] = $srch_addr;
-                        if (strtolower($cc->personal) == strtolower($srch_addr->personal)) {
+                        if ($cc->personal == $srch_addr->personal) {
                             if ($recurs) {
                                 return array($results, true);
                             } else {
@@ -993,3 +941,4 @@ class Rfc822Header {
     }
 }
 
+?>
