@@ -1,16 +1,23 @@
 <?php
+
 /**
  * Administrator plugin - Option definitions
  *
- * @version $Id: defines.php,v 1.32.2.12 2006/02/03 22:27:51 jervfors Exp $
  * @author Philippe Mingo
- * @copyright (c) 1999-2006 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: defines.php,v 1.68 2006/02/09 19:38:50 tokul Exp $
  * @package plugins
  * @subpackage administrator
  */
 
-/** */
+/** @ignore */
+if (!defined('SM_PATH')) define('SM_PATH','../../');
+
+/**
+ * Load SquirrelMail SMPREF constants for default_unseen_notify and 
+ * default_unseen_type variables.
+ */
 require_once( SM_PATH . 'functions/constants.php' );
 
 /* Define constants for the various option types. */
@@ -28,10 +35,25 @@ define('SMOPT_TYPE_TITLE', 9);
 define('SMOPT_TYPE_THEME', 10);
 define('SMOPT_TYPE_PLUGINS', 11);
 define('SMOPT_TYPE_LDAP', 12);
+define('SMOPT_TYPE_CUSTOM', 13);
 define('SMOPT_TYPE_EXTERNAL', 32);
 define('SMOPT_TYPE_PATH',33);
 
-global $languages;
+/**
+ * Returns reformated aTemplateSet array data for option selection
+ * @return array template selection options
+ * @since 1.5.1
+ */
+function adm_template_options() {
+    global $aTemplateSet;
+    $ret = array();
+    foreach ($aTemplateSet as $iTemplateID => $aTemplate) {
+        $ret[$iTemplateID] = $aTemplate['NAME'];
+    }
+    return $ret;
+}
+
+global $languages, $version;
 
 $language_values = array( );
 foreach ($languages as $lang_key => $lang_attributes) {
@@ -106,6 +128,7 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                                    'courier' => _("Courier IMAP server"),
                                                                    'macosx' => _("Mac OS X Mailserver"),
                                                                    'hmailserver' => _("hMailServer IMAP server"),
+                                                                   'mercury32' => _("Mercury/32 IMAP server"),
                                                                    'bincimap' => _("Binc IMAP server"),
                                                                    'other' => _("Not one of the above servers") ) ),
                  '$optional_delimiter' => array( 'name' => _("IMAP Folder Delimiter"),
@@ -113,10 +136,13 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                  'comment' => _("Use &quot;detect&quot; to auto-detect."),
                                                  'size' => 10,
                                                  'default' => 'detect' ),
-                 '$use_imap_tls' => array( 'name' => _("Use TLS for IMAP Connections"),
-                                           'type' => SMOPT_TYPE_BOOLEAN,
-                                           'comment' => _("Requires PHP 4.3.x! Experimental."),
-                                           'default' => false ),
+                 '$use_imap_tls' => array( 'name' => _("IMAP Connection Security"),
+                                           'type' => SMOPT_TYPE_STRLIST,
+                                           'posvals' => array( 0 => _("Plain text connection"),
+                                                               1 => _("Secure IMAP (TLS) connection"),
+                                                               2 => _("IMAP STARTTLS connection")),
+                                           'comment' => _("Requires higher PHP version and special functions. See SquirrelMail documentation."),
+                                           'default' => 0 ),
                  '$imap_auth_mech' => array( 'name' => _("IMAP Authentication Type"),
                                              'type' => SMOPT_TYPE_STRLIST,
                                              'posvals' => array('login' => _("IMAP login"),
@@ -129,15 +155,21 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                  '$sendmail_path' => array( 'name' => _("Sendmail Path"),
                                             'type' => SMOPT_TYPE_STRING,
                                             'size' => 40 ),
+                 '$sendmail_args' => array( 'name' => _("Sendmail Arguments"),
+                                            'type' => SMOPT_TYPE_STRING,
+                                            'size' => 40 ),
                  '$smtpServerAddress' => array( 'name' => _("SMTP Server Address"),
                                                 'type' => SMOPT_TYPE_STRING,
                                                 'size' => 40 ),
                  '$smtpPort' => array( 'name' => _("SMTP Server Port"),
                                        'type' => SMOPT_TYPE_INTEGER ),
-                 '$use_smtp_tls' => array( 'name' => _("Use TLS for SMTP Connections"),
-                                           'type' => SMOPT_TYPE_BOOLEAN,
-                                           'comment' => _("Requires PHP 4.3.x! Experimental."),
-                                           'default' => false ),
+                 '$use_smtp_tls' => array( 'name' => _("SMTP Connection Security"),
+                                           'type' => SMOPT_TYPE_STRLIST,
+                                           'posvals' => array( 0 => _("Plain text connection"),
+                                                               1 => _("Secure IMAP (TLS) connection"),
+                                                               2 => _("IMAP STARTTLS connection")),
+                                           'comment' => _("Requires higher PHP version and special functions. See SquirrelMail documentation."),
+                                           'default' => 0 ),
                  '$smtp_auth_mech' => array( 'name' => _("SMTP Authentication Type"),
                                              'type' => SMOPT_TYPE_STRLIST,
                                              'posvals' => array('none' => _("No SMTP auth"),
@@ -149,7 +181,7 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                               'type' => SMOPT_TYPE_BOOLEAN,
                                               'default' => false ),
                  '$encode_header_key' => array( 'name' => _("Header Encryption Key"),
-                                                'type' => SMOPT_TYPE_STRING ),
+                                          'type' => SMOPT_TYPE_STRING ),
                  '$invert_time' => array( 'name' => _("Invert Time"),
                                           'type' => SMOPT_TYPE_BOOLEAN ),
                  /* --------------------------------------------------------*/
@@ -235,27 +267,37 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                  '$hide_auth_header' => array( 'name' => _("Remove username from headers"),
                                                'comment' => _("Used only when identities can't be modified"),
                                                'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$allow_server_sort' => array( 'name' => _("Use server-side sorting"),
+                 '$disable_server_sort' => array( 'name' => _("Disable server-side sorting"),
                                                 'type' => SMOPT_TYPE_BOOLEAN,
                                                 'default' => false ),
-                 '$allow_thread_sort' => array( 'name' => _("Use server-side thread sorting"),
+                 '$disable_thread_sort' => array( 'name' => _("Disable server-side thread sorting"),
                                                 'type' => SMOPT_TYPE_BOOLEAN,
                                                 'default' => false ),
                  '$allow_charset_search' => array( 'name' => _("Allow server charset search"),
                                                    'type' => SMOPT_TYPE_BOOLEAN,
                                                    'default' => false ),
-                 '$uid_support' => array( 'name' => _("UID support"),
-                                          'type' => SMOPT_TYPE_BOOLEAN,
-                                          'default' => false ),
+                 '$allow_advanced_search' => array( 'name' => _("Search functions"),
+                                                    'type' => SMOPT_TYPE_NUMLIST,
+                                                    'posvals' => array( 0 => _("Only basic search"),
+                                                                        1 => _("Only advanced search"),
+                                                                        2 => _("Both search functions") ),
+                                                    'default' => 0 ),
                  '$session_name' => array( 'name' => _("PHP session name"),
                                            'type' => SMOPT_TYPE_HIDDEN ),
+                 '$time_zone_type' => array( 'name' => _("Time Zone Configuration"),
+                                             'type' => SMOPT_TYPE_NUMLIST,
+                                             'posvals' => array( 0 => _("Standard GNU C time zones"),
+                                                                 1 => _("Strict time zones"),
+                                                                 2 => _("Custom GNU C time zones"),
+                                                                 3 => _("Custom strict time zones")),
+                                             'default' => 0 ),
                  /* --------------------------------------------------------*/
                  'Group5' => array( 'name' => _("Message of the Day"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$motd' => array( 'name' => _("Message of the Day"),
                                    'type' => SMOPT_TYPE_TEXTAREA,
                                    'size' => 40 ),
-                 /* --------------------------------------------------------*/
+                 /* ---- Database settings ---- */
                  'Group6' => array( 'name' => _("Database"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$addrbook_dsn' => array( 'name' => _("Address book DSN"),
@@ -276,14 +318,20 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                               'type' => SMOPT_TYPE_STRING,
                                               'size' => 40,
                                               'default' => 'user' ),
+                 '$prefs_user_size' => array( 'name' => _("Size of username field"),
+                                              'type' => SMOPT_TYPE_INTEGER ),
                  '$prefs_key_field' => array('name' => _("Preferences key field"),
                                              'type' => SMOPT_TYPE_STRING,
                                              'size' => 40,
                                              'default' => 'prefkey' ),
+                 '$prefs_key_size' => array( 'name' => _("Size of key field"),
+                                             'type' => SMOPT_TYPE_INTEGER ),
                  '$prefs_val_field' => array('name' => _("Preferences value field"),
                                              'type' => SMOPT_TYPE_STRING,
                                              'size' => 40,
                                              'default' => 'prefval' ),
+                 '$prefs_val_size' => array( 'name' => _("Size of value field"),
+                                             'type' => SMOPT_TYPE_INTEGER ),
                  '$addrbook_global_dsn' => array( 'name' => _("Global address book DSN"),
                                            'type' => SMOPT_TYPE_STRING,
                                            'size' => 40 ),
@@ -319,28 +367,57 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                                   'windows-1255' => 'windows-1255',
                                                                   'windows-1256' => 'windows-1256',
                                                                   'iso-2022-jp' => 'iso-2022-jp' ) ),
-                  '$lossy_encoding'  => array( 'name' => _("Enable lossy encoding"),
-                                               'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$show_alternative_names'  => array( 'name' => _("Show alternative language names"),
+                                                      'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$aggressive_decoding'  => array( 'name' => _("Enable aggressive decoding"),
+                                                 'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$lossy_encoding'  => array( 'name' => _("Enable lossy encoding"),
+                                                 'type' => SMOPT_TYPE_BOOLEAN ),
+                 /* ---- Tweaks ---- */
+                 'Group10' => array( 'name' => _("Tweaks"),
+                                     'type' => SMOPT_TYPE_TITLE ),
+                 '$advanced_tree'  => array( 'name' => _("Use advanced tree folder listing"),
+                                             'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$use_icons'  => array( 'name' => _("Use icons"),
+                                         'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$use_iframe' => array( 'name' => _("Use inline frames with HTML mails"),
+                                         'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$use_php_recode'  => array( 'name' => _("Use PHP recode functions"),
+                                              'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$use_php_iconv'  => array( 'name' => _("Use PHP iconv functions"),
+                                             'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$allow_remote_configtest' => array( 'name' => _("Allow remote configuration test"),
+                                                      'type' => SMOPT_TYPE_BOOLEAN ),
                  /* ---- Settings of address books ---- */
-                 'Group10' => array( 'name' => _("Address Books"),
+                 'Group11' => array( 'name' => _("Address Books"),
                                      'type' => SMOPT_TYPE_TITLE ),
                  '$default_use_javascript_addr_book' => array( 'name' => _("Default Javascript Addressbook"),
                                                   'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$abook_global_file' => array( 'name' => _("Global address book file"),
-                                                  'type' => SMOPT_TYPE_STRING ),
+                 '$abook_global_file'           => array( 'name' => _("Global address book file"),
+                                                          'type' => SMOPT_TYPE_STRING ),
                  '$abook_global_file_writeable' => array( 'name' => _("Allow writing into global address book file"),
-                                                  'type' => SMOPT_TYPE_BOOLEAN ),
+                                                          'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$abook_global_file_listing'   => array( 'name' => _("Allow listing of global address book"),
+                                                          'type' => SMOPT_TYPE_BOOLEAN ),
                  /* --------------------------------------------------------*/
-                 'Group7' => array( 'name' => _("Themes"),
+                 'Group7' => array( 'name' => _("Templates"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$theme_css' => array( 'name' => _("Style Sheet URL (css)"),
                                         'type' => SMOPT_TYPE_PATH,
                                         'size' => 40 ),
+                 '$default_fontsize' => array( 'name' => _("Default font size"),
+                                               'type' => SMOPT_TYPE_STRING,
+                                               'default' => ''),
+                 '$default_fontset' => array( 'name' => _("Default font set"),
+                                              'type' => SMOPT_TYPE_STRLIST,
+                                              'posvals' => $fontsets),
+                 '$templateset_default' => array( 'name' => _("Default template"),
+                                                  'type' => SMOPT_TYPE_STRLIST,
+                                                  'posvals' => adm_template_options()),
                  '$theme_default' => array( 'name' => _("Default theme"),
                                             'type' => SMOPT_TYPE_INTEGER,
                                             'default' => 0,
                                             'comment' => _("Use index number of theme") ),
-                 /* ---- Group8 is for plugins ---- */
                  /* --------------------------------------------------------*/
                  '$config_use_color' => array( 'name' => '',
                                                'type' => SMOPT_TYPE_HIDDEN ),
