@@ -3,14 +3,14 @@
 /**
  * options_identities.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * Display Identities Options
  *
- * @version $Id: options_identities.php,v 1.22.2.6 2005/07/01 08:04:48 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: options_identities.php,v 1.43 2006/01/23 18:43:28 tokul Exp $
  * @package squirrelmail
  * @subpackage prefs
+ * @since 1.1.3
  */
 
 /**
@@ -43,8 +43,8 @@ if (!empty($smaction) && is_array($smaction)) {
         // we only need to extract the action and the identity we are
         // altering
 
-        foreach($row as $key=>$data) {
-            $identid = $key;
+        foreach($row as $iKey=>$data) {
+            $identid = $iKey;
         }
 
         $doaction = $action;
@@ -61,21 +61,22 @@ if (!empty($return)) {
 
 displayPageHeader($color, 'None');
 
+/* since 1.1.3 */
 do_hook('options_identities_top');
 
 $td_str = '';
 $td_str .= '<form name="f" action="options_identities.php" method="post"><br />' . "\n";
 $td_str .= '<table border="0" cellspacing="0" cellpadding="0" width="100%">' . "\n";
 $cnt = count($identities);
-foreach( $identities as $key=>$ident ) {
+foreach( $identities as $iKey=>$ident ) {
 
-    if ($key == 0) {
+    if ($iKey == 0) {
         $hdr_str = _("Default Identity");
     } else {
-        $hdr_str = sprintf( _("Alternate Identity %d"), $key);
+        $hdr_str = sprintf( _("Alternate Identity %d"), $iKey);
     }
 
-    $td_str .= ShowIdentityInfo( $hdr_str, $ident, $key );
+    $td_str .= ShowIdentityInfo( $hdr_str, $ident, $iKey );
 
 }
 
@@ -86,7 +87,7 @@ $td_str .= '</form>';
 echo '<br /> ' . "\n" .
     html_tag('table', "\n" .
         html_tag('tr', "\n" .
-            html_tag('td' , "\n" . 
+            html_tag('td' , "\n" .
             '<b>' . _("Options") . ' - ' . _("Advanced Identities") . '</b><br />' .
             html_tag('table', "\n" .
                 html_tag('tr', "\n" .
@@ -101,8 +102,31 @@ echo '<br /> ' . "\n" .
             '', '', 'width="100%" border="0" cellpadding="1" cellspacing="1"' )) ,
         'center', $color[0]),
     'center', '', 'width="95%" border="0" cellpadding="2" cellspacing="0"' ) . '</body></html>';
-                    
 
+/**
+ * Returns html formated identity form fields
+ *
+ * Contains options_identities_buttons and option_identities_table hooks.
+ * Before 1.4.5/1.5.1 hooks were placed in ShowTableInfo() function.
+ * In 1.1.3-1.4.1 they were called in do_hook function with two or
+ * three arguments. Since 1.4.1 hooks are called in concat_hook_function.
+ * Arguments are moved to array.
+ *
+ * options_identities_buttons hook uses array with two keys. First array key is
+ * boolean variable used to indicate empty identity field. Second array key
+ * is integer variable used to indicate identity number
+ *
+ * options_identities_table hook uses array with three keys. First array key is
+ * a string containing background color style CSS (1.4.1-1.4.4/1.5.0 uses only
+ * html color code). Second array key is boolean variable used to indicate empty
+ * identity field. Third array key is integer variable used to indicate identity
+ * number
+ * @param string $title Name displayed in header row
+ * @param array $identity Identity information
+ * @param integer $id identity ID
+ * @return string html formatted table rows with form fields for identity management
+ * @since 1.5.1 and 1.4.5 (was called ShowTableInfo() in 1.1.3-1.4.4 and 1.5.0)
+ */
 function ShowIdentityInfo($title, $identity, $id ) {
     global $color;
 
@@ -153,26 +177,48 @@ function ShowIdentityInfo($title, $identity, $id ) {
 
 }
 
+/**
+ * Creates html formated table row with input field
+ * @param string $title Name displayed next to input field
+ * @param string $name Name of input field
+ * @param string $data Default value of input field (data is sanitized with htmlspecialchars)
+ * @param string $bgcolor html attributes added to row element (tr)
+ * @return string html formated table row with text input field
+ * @since 1.2.0 (arguments differ since 1.4.5/1.5.1)
+ * @todo check right-to-left language issues
+ * @access private
+ */
 function sti_input( $title, $name, $data, $bgcolor ) {
     $str = '';
     $str .= '<tr' . $bgcolor . ">\n";
     $str .= '  <td style="white-space: nowrap;text-align:right;">' . $title . ' </td>' . "\n";
     $str .= '  <td> <input type="text" name="' . $name . '" size="50" value="'. htmlspecialchars($data) . '"> </td>' . "\n";
     $str .= '</tr>';
-    
+
     return $str;
 
 }
 
+/**
+ * Creates html formated table row with textarea field
+ * @param string $title Name displayed next to textarea field
+ * @param string $name Name of textarea field
+ * @param string $data Default value of textarea field  (data is sanitized with htmlspecialchars)
+ * @param string $bgcolor html attributes added to row element (tr)
+ * @return string html formated table row with textarea
+ * @since 1.2.5 (arguments differ since 1.4.5/1.5.1)
+ * @todo check right-to-left language issues
+ * @access private
+ */
 function sti_textarea( $title, $name, $data, $bgcolor ) {
     $str = '';
     $str .= '<tr' . $bgcolor . ">\n";
     $str .= '  <td style="white-space: nowrap;text-align:right;">' . $title . ' </td>' . "\n";
     $str .= '  <td> <textarea name="' . $name . '" cols="50" rows="5">'. htmlspecialchars($data) . '</textarea> </td>' . "\n";
     $str .= '</tr>';
-    
+
     return $str;
 
 }
 
-?>
+?>
\ No newline at end of file
