@@ -6,15 +6,12 @@
  * top frame of printer_friendly_main.php
  * displays some javascript buttons for printing & closing
  *
- * @copyright &copy; 1999-2009 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: printer_friendly_top.php 13549 2009-04-15 22:00:49Z jervfors $
+ * @version $Id: printer_friendly_top.php,v 1.29 2006/02/05 11:32:33 jervfors Exp $
  * @package squirrelmail
  */
 
-/** This is the printer_friendly_top page */
-define('PAGE_NAME', 'printer_friendly_top');
-
 /**
  * Path for SquirrelMail required files.
  * @ignore
@@ -22,10 +19,10 @@ define('PAGE_NAME', 'printer_friendly_top');
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
-require_once(SM_PATH . 'include/validate.php');
+include_once(SM_PATH . 'include/validate.php');
 
 displayHtmlHeader( _("Printer Friendly"),
-             "<script language=\"javascript\" type=\"text/javascript\">\n".
+             "<script type=\"text/javascript\">\n".
              "<!--\n".
              "function printPopup() {\n".
                 "parent.frames[1].focus();\n".
@@ -37,12 +34,11 @@ displayHtmlHeader( _("Printer Friendly"),
 
 echo '<body text="'.$color[8].'" bgcolor="'.$color[3].'" link="'.$color[7].'" vlink="'.$color[7].'" alink="'.$color[7]."\">\n" .
      html_tag( 'div',
-         '<b>'.
          '<form>'.
          '<input type="button" value="' . _("Print") . '" onclick="printPopup()" /> '.
          '<input type="button" value="' . _("Close") . '" onclick="window.parent.close()" />'.
-         '</form>'.
-         '</b>',
+         '</form>',
      'right' );
-?>
-</body></html>
\ No newline at end of file
+
+$oTemplate->display('footer.tpl');
+?>
\ No newline at end of file
