@@ -5,15 +5,12 @@
  *
  * Derived from webmail.php by Ralf Kraudelt <kraude@wiwi.uni-rostock.de>
  *
- * @copyright &copy; 1999-2007 The SquirrelMail Project Team
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: redirect.php 13290 2008-09-28 13:45:49Z kink $
+ * @version $Id: redirect.php,v 1.94 2006/02/08 07:58:18 stekkel Exp $
  * @package squirrelmail
  */
 
-/** This is the redirect page */
-define('PAGE_NAME', 'redirect');
-
 /**
  * Path for SquirrelMail required files.
  * @ignore
@@ -24,17 +21,24 @@ define('SM_PATH','../');
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/i18n.php');
 require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'config/config.php');
 require_once(SM_PATH . 'functions/prefs.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/constants.php');
 require_once(SM_PATH . 'functions/page_header.php');
 
+/* Before starting the session, the base URI must be known. Assuming */
+/* that this file is in the src/ subdirectory (or something).        */
+if (!function_exists('sqm_baseuri')){
+    require_once(SM_PATH . 'functions/display_messages.php');
+}
 $base_uri = sqm_baseuri();
 
 header('Pragma: no-cache');
 $location = get_location();
 
+session_set_cookie_params (0, $base_uri);
 sqsession_is_active();
 
 sqsession_unregister ('user_is_logged_in');
@@ -43,21 +47,19 @@ sqsession_register ($base_uri, 'base_uri');
 /* get globals we me need */
 sqGetGlobalVar('login_username', $login_username);
 sqGetGlobalVar('secretkey', $secretkey);
-sqGetGlobalVar('js_autodetect_results', $js_autodetect_results);
 if(!sqGetGlobalVar('squirrelmail_language', $squirrelmail_language) || $squirrelmail_language == '') {
     $squirrelmail_language = $squirrelmail_default_language;
 }
-
-if (!sqgetGlobalVar('mailtodata', $mailtodata)) {
-    $mailtodata = '';
+if (!sqgetGlobalVar('mailto', $mailto)) {
+    $mailto = '';
 }
 
-
 /* end of get globals */
 
 set_up_language($squirrelmail_language, true);
 /* Refresh the language cookie. */
-sqsetcookie('squirrelmail_language', $squirrelmail_language, time()+2592000, $base_uri);
+sqsetcookie('squirrelmail_language', $squirrelmail_language, time()+2592000,
+          $base_uri);
 
 if (!isset($login_username)) {
     include_once(SM_PATH .  'functions/display_messages.php' );
@@ -83,6 +85,19 @@ if (!sqsession_is_registered('user_is_logged_in')) {
     $imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, 0);
 
     $sqimap_capabilities = sqimap_capability($imapConnection);
+
+    /* Server side sorting control */
+    if (isset($sqimap_capabilities['SORT']) && $sqimap_capabilities['SORT'] == true &&
+        isset($disable_server_sort) && $disable_server_sort) {
+        unset($sqimap_capabilities['SORT']);
+    }
+
+    /* Thread sort control */
+    if (isset($sqimap_capabilities['THREAD']) && $sqimap_capabilities['THREAD'] == true &&
+        isset($disable_thread_sort) && $disable_thread_sort) {
+        unset($sqimap_capabilities['THREAD']);
+    }
+
     sqsession_register($sqimap_capabilities, 'sqimap_capabilities');
     $delimiter = sqimap_get_delimiter ($imapConnection);
 
@@ -91,7 +106,7 @@ if (!sqsession_is_registered('user_is_logged_in')) {
 
     $username = $login_username;
     sqsession_register ($username, 'username');
-    sqsetcookie('key', $key, 0, $base_uri);
+    sqsetcookie('key', $key, false, $base_uri);
     do_hook ('login_verified');
 
 }
@@ -110,66 +125,43 @@ $attachment_common_types_parsed = array();
 sqsession_register($attachment_common_types, 'attachment_common_types');
 sqsession_register($attachment_common_types_parsed, 'attachment_common_types_parsed');
 
+$debug = false;
 
 if ( sqgetGlobalVar('HTTP_ACCEPT', $http_accept, SQ_SERVER) &&
     !isset($attachment_common_types_parsed[$http_accept]) ) {
-    attachment_common_parse($http_accept);
+    attachment_common_parse($http_accept, $debug);
 }
 
 /* Complete autodetection of Javascript. */
-$javascript_setting = getPref
-    ($data_dir, $username, 'javascript_setting', SMPREF_JS_AUTODETECT);
-$js_autodetect_results = (isset($js_autodetect_results) ?
-    $js_autodetect_results : SMPREF_JS_OFF);
-/* See if it's set to "Always on" */
-$js_pref = SMPREF_JS_ON;
-if ($javascript_setting != SMPREF_JS_ON){
-    if ($javascript_setting == SMPREF_JS_AUTODETECT) {
-        if ($js_autodetect_results == SMPREF_JS_OFF) {
-            $js_pref = SMPREF_JS_OFF;
-        }
-    } else {
-        $js_pref = SMPREF_JS_OFF;
-    }
-}
-/* Update the prefs */
-setPref($data_dir, $username, 'javascript_on', $js_pref);
+checkForJavascript();
 
 /* Compute the URL to forward the user to. */
-$redirect_url = 'webmail.php';
+$redirect_url = $location . '/webmail.php';
 
 if ( sqgetGlobalVar('session_expired_location', $session_expired_location, SQ_SESSION) ) {
     sqsession_unregister('session_expired_location');
-    if ( $session_expired_location == 'compose' ) {
-        $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
-        if ($compose_new_win) {
-            // do not prefix $location here because $session_expired_location is set to the PAGE_NAME
-            // of the last page
-            $redirect_url = $session_expired_location . '.php';
-        } else {
-            $redirect_url = 'webmail.php?right_frame=' . urlencode($session_expired_location . '.php');
-        }
-    } else if ($session_expired_location != 'webmail'
-            && $session_expired_location != 'left_main') {
-        $redirect_url = 'webmail.php?right_frame=' . urlencode($session_expired_location . '.php');
+    $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
+    if ($compose_new_win) {
+        // do not prefix $location here because $session_expired_location is set to PHP_SELF
+        // of the last page
+        $redirect_url = $session_expired_location;
+    } elseif ( strpos($session_expired_location, 'webmail.php') === FALSE ) {
+        $redirect_url = $location.'/webmail.php?right_frame='.urldecode($session_expired_location);
     }
     unset($session_expired_location);
 }
-
-if($mailtodata != '') {
-    $redirect_url  = $location . '/webmail.php?right_frame=compose.php&mailtodata=';
-    $redirect_url .= urlencode($mailtodata);
+if($mailto != '') {
+    $redirect_url  = $location . '/webmail.php?right_frame=compose.php&mailto=';
+    $redirect_url .= urlencode($mailto);
 }
 
-
-
 /* Write session data and send them off to the appropriate page. */
 session_write_close();
 header("Location: $redirect_url");
 
 /* --------------------- end main ----------------------- */
 
-function attachment_common_parse($str) {
+function attachment_common_parse($str, $debug) {
     global $attachment_common_types, $attachment_common_types_parsed;
 
     $attachment_common_types_parsed[$str] = true;
@@ -195,3 +187,4 @@ function attachment_common_parse($str) {
     sqsession_register($attachment_common_types, 'attachment_common_types');
 }
 
+?>
\ No newline at end of file
