@@ -3,14 +3,13 @@
 /**
  * webmail.php -- Displays the main frameset
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
  * This file generates the main frameset. The files that are
  * shown can be given as parameters. If the user is not logged in
  * this file will verify username and password.
  *
- * @version $Id: webmail.php,v 1.92.2.11 2005/05/20 18:43:39 kink Exp $
+ * @copyright &copy; 1999-2006 The SquirrelMail Project Team
+ * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * @version $Id: webmail.php,v 1.118.2.1 2006/02/13 18:20:06 kink Exp $
  * @package squirrelmail
  */
 
@@ -40,7 +39,7 @@ sqsession_is_active();
 sqgetGlobalVar('username', $username, SQ_SESSION);
 sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
-sqgetGlobalVar('right_frame', $right_frame, SQ_GET);
+
 if (sqgetGlobalVar('sort', $sort)) {
     $sort = (int) $sort;
 }
@@ -53,15 +52,15 @@ if (!sqgetGlobalVar('mailbox', $mailbox)) {
     $mailbox = 'INBOX';
 }
 
+sqgetGlobalVar('right_frame', $right_frame, SQ_GET);
+
 if ( isset($_SESSION['session_expired_post']) ) {
     sqsession_unregister('session_expired_post');
 }
-
 if(!sqgetGlobalVar('mailto', $mailto)) {
     $mailto = '';
 }
 
-
 is_logged_in();
 
 do_hook('webmail_top');
@@ -75,17 +74,31 @@ do_hook('webmail_top');
  */
 $my_language = getPref($data_dir, $username, 'language');
 if ($my_language != $squirrelmail_language) {
-    setcookie('squirrelmail_language', $my_language, time()+2592000, $base_uri);
+    sqsetcookie('squirrelmail_language', $my_language, time()+2592000, $base_uri);
 }
 
-set_up_language(getPref($data_dir, $username, 'language'));
+$err=set_up_language(getPref($data_dir, $username, 'language'));
 
-$output = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\">\n".
+$output = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\"\n".
+          "  \"http://www.w3.org/TR/1999/REC-html401-19991224/frameset.dtd\">\n".
           "<html><head>\n" .
           "<meta name=\"robots\" content=\"noindex,nofollow\">\n" .
           "<title>$org_title</title>\n".
           "</head>";
 
+// Japanese translation used without mbstring support
+if ($err==2) {
+    echo $output.
+         "<body>\n".
+         "<p>You need to have PHP installed with the multibyte string function \n".
+         "enabled (using configure option --enable-mbstring).</p>\n".
+         "<p>System assumed that you accidently switched to Japanese translation \n".
+         "and reverted your language preference to English.</p>\n".
+         "<p>Please refresh this page in order to use webmail.</p>\n".
+         "</body></html>";
+    return;
+}
+
 $left_size = getPref($data_dir, $username, 'left_size');
 $location_of_bar = getPref($data_dir, $username, 'location_of_bar');
 
@@ -128,45 +141,61 @@ else {
  *
  * This was done to create a pure HTML way of refreshing the folder list since
  * we would like to use as little Javascript as possible.
+ *
+ * The test for // should catch any attempt to include off-site webpages into
+ * our frameset.
  */
 
-if (empty($right_frame) || (strpos(urldecode($right_frame), '://'))) {
+if (empty($right_frame) || (strpos(urldecode($right_frame), '//') !== false)) {
     $right_frame = '';
 }
 
- 
-if ($right_frame == 'right_main.php') {
-    $urlMailbox = urlencode($mailbox);
-    $right_frame_url = "right_main.php?mailbox=$urlMailbox"
+if ( strpos($right_frame,'?') ) {
+    $right_frame_file = substr($right_frame,0,strpos($right_frame,'?'));
+} else {
+    $right_frame_file = $right_frame;
+}
+
+switch($right_frame) {
+    case 'right_main.php':
+        $right_frame_url = "right_main.php?mailbox=".urlencode($mailbox)
                        . (!empty($sort)?"&amp;sort=$sort":'')
                        . (!empty($startMessage)?"&amp;startMessage=$startMessage":'');
-} elseif ($right_frame == 'options.php') {
-    $right_frame_url = 'options.php';
-} elseif ($right_frame == 'folders.php') {
-    $right_frame_url = 'folders.php';
-} elseif ($right_frame == 'compose.php') {
-    $right_frame_url = 'compose.php?' . $mailto;
-} else if ($right_frame == '') {
-    $right_frame_url = 'right_main.php';
-} else {
-    $right_frame_url =  htmlspecialchars($right_frame);
-}
-
+        break;
+    case 'options.php':
+        $right_frame_url = 'options.php';
+        break;
+    case 'folders.php':
+        $right_frame_url = 'folders.php';
+        break;
+    case 'compose.php':
+        $right_frame_url = 'compose.php?' . $mailto;
+        break;
+    case '':
+        $right_frame_url = 'right_main.php';
+        break;
+    default:
+        $right_frame_url =  urlencode($right_frame);
+        break;
+} 
 
+$left_frame  = '<frame src="left_main.php" name="left" frameborder="1" title="'.
+               _("Folder List") ."\" />\n";
+$right_frame = '<frame src="'.$right_frame_url.'" name="right" frameborder="1" title="'.
+               _("Message List") ."\" />\n";
 
 if ($location_of_bar == 'right') {
-    $output .= "<frame src=\"$right_frame_url\" name=\"right\" frameborder=\"1\" />\n" .
-               "<frame src=\"left_main.php\" name=\"left\" frameborder=\"1\" />\n";
+    $output .= $right_frame . $left_frame;
 }
 else {
-    $output .= "<frame src=\"left_main.php\" name=\"left\" frameborder=\"1\" />\n".
-               "<frame src=\"$right_frame_url\" name=\"right\" frameborder=\"1\" />\n";
+    $output .= $left_frame . $right_frame;
 }
 $ret = concat_hook_function('webmail_bottom', $output);
 if($ret != '') {
     $output = $ret;
 }
 echo $output;
+
 ?>
 </frameset>
 </html>
